@@ -1,10 +1,7 @@
 import os, json, time
 from typing import List, Optional, Tuple, Union
 from ddd_objects.infrastructure.repository_impl import RepositoryImpl
-from ddd_objects.infrastructure.repository_impl import (
-    RepositoryImpl, 
-)
-from ddd_objects.lib import Logger, get_md5
+from ddd_objects.lib import Logger
 from .ao import K3SController
 from .converter import(
     CommandResultConverter,
@@ -344,6 +341,21 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
             namespace_name=namespace_name
         )
 
+    def delete_pod(
+        self, 
+        cluster_name: Name, 
+        namespace_name: Name,
+        pod_name: Name
+    )->bool:
+        cluster_name = cluster_name.get_value()
+        namespace_name = namespace_name.get_value()
+        pod_name = pod_name.get_value()
+        result = self.ao.delete_pod(cluster_name, namespace_name, pod_name)
+        if result.succeed:
+            return result.get_value()
+        else:
+            return False
+
     def _get_pod_containers(self, cluster_name: Name, namespace_name: Name)->Optional[List[Pod]]:
         cluster_name = cluster_name.get_value()
         namespace_name = namespace_name.get_value()
